@@ -1,22 +1,36 @@
-test_that("bfs_get_catalog_data() returns a none-empty data.frame", {
+test_that("bfs_get_catalog_data() returns a data.frame of 5 rows", {
   if (!curl::has_internet()) {
     skip("No internet connection")
   }
-  df_catalog_data <- bfs_get_catalog_data(prodima = c(900210, 900212), skip_limit = FALSE)
+  df_catalog_data <- bfs_get_catalog_data(limit = 5)
   expect_s3_class(df_catalog_data, "data.frame")
-  expect_equal(nrow(df_catalog_data), 40)
+  expect_true(nrow(df_catalog_data) == 5)
 })
 test_that("bfs_get_catalog_data() using some arguments", {
   if (!curl::has_internet()) {
     skip("No internet connection")
   }
-  df_catalog_data <- bfs_get_catalog_data(title = "studierende", prodima = c(900210, 900212), spatial_division = "Switzerland", skip_limit = FALSE)
+  df_catalog_data <- bfs_get_catalog_data(title = "studierende", spatial_division = "Switzerland", limit = 5)
   expect_s3_class(df_catalog_data, "data.frame")
 })
 test_that("bfs_get_catalog_data() using order_nr argument", {
   if (!curl::has_internet()) {
     skip("No internet connection")
   }
-  df_catalog_data <- bfs_get_catalog_data(order_nr = "px-x-1502040100_131", prodima = c(900210, 900212), skip_limit = FALSE)
+  df_catalog_data <- bfs_get_catalog_data(order_nr = "px-x-1502040100_131")
   expect_s3_class(df_catalog_data, "data.frame")
 })
+test_that("bfs_get_catalog_data() using order_nr argument", {
+  if (!curl::has_internet()) {
+    skip("No internet connection")
+  }
+  df_catalog_data <- bfs_get_catalog_data(order_nr = "px-x-1502040100_131")
+  expect_s3_class(df_catalog_data, "data.frame")
+})
+test_that("bfs_get_catalog_data() using prodima argument", {
+  if (!curl::has_internet()) {
+    skip("No internet connection")
+  }
+  df_catalog_data <- bfs_get_catalog_data(prodima = 900210, limit = 5)
+  expect_s3_class(df_catalog_data, "data.frame")
+})
\ No newline at end of file
